@@ -1,8 +1,6 @@
 package App::Base::Script::Common;
 use 5.010;
 use Moose::Role;
-our $VERSION = "0.04";
-$VERSION = eval $VERSION;
 
 =head1 NAME
 
@@ -10,21 +8,18 @@ App::Base::Script::Common - Behaviors common to App::Base::Script and App::Base:
 
 =head1 VERSION
 
-This document describes App::Base version 0.04
+This document describes App::Base version 0.05
 
 =head1 DESCRIPTION
 
 App::Base::Script::Common provides infrastructure that is common to the
-App::Base::Script and App::Base::Daemon classes, including options parsing and
-logging methods.
+App::Base::Script and App::Base::Daemon classes, including options parsing.
 
 =cut
 
 use App::Base::Script::Option;
-use Log::Log4perl qw(:nowarn);
 
 use Cwd qw( abs_path );
-use Carp qw( croak );
 use Getopt::Long;
 use IO::Handle;
 use List::Util qw( max );
@@ -129,7 +124,7 @@ has 'parsed_args' => (
 
 =head2 script_name
 
-The name of the running script, computed from $0 and used for logging.
+The name of the running script, computed from $0.
 
 =cut
 
@@ -138,30 +133,6 @@ has 'script_name' => (
     default => sub { path($0)->basename; },
 );
 
-=head2 logger
-
-Logger object used for logging. Should implement debug, info, warn and error
-methods. By default L<Log::Log4perl> is used.
-
-=cut
-
-has logger => (
-    is      => 'ro',
-    lazy    => 1,
-    builder => '_build_logger',
-    handles => {
-        debug   => 'debug',
-        info    => 'info',
-        warn    => 'warn',
-        notice  => 'info',
-        warning => 'warn',
-    },
-);
-
-sub _build_logger {
-    return Log::Log4perl::get_logger();
-}
-
 =head1 METHODS
 
 =head2 BUILDARGS
@@ -282,7 +253,6 @@ Outputs a statement explaining the usage of the script, then exits.
 
 sub usage {
     my $self      = shift;
-    my $log_error = shift;
 
     my $col_width = $ENV{COLUMNS} || 76;
 
@@ -302,7 +272,7 @@ sub usage {
 
     print STDERR $message;
 
-    return $log_error ? $self->error($message) : ( exit 1 );
+    exit(1);
 
 }
 
@@ -323,7 +293,7 @@ sub getOption {
         return $self->_option_values->{$option};
     }
     else {
-        croak "Unknown option $option";
+        die "Unknown option $option";
     }
 
 }
@@ -412,7 +382,7 @@ SUBCLASS METHODS), then exits.
 
 sub __error {
     my $self = shift;
-    $self->logger->error( join " ", @_ );
+    warn( join " ", @_ );
     exit(-1);
 }
 
@@ -450,22 +420,6 @@ Every such class has one important attribute: options -- an array ref of hashes
 describing options to be added to the command-line processing for the script.
 See L<App::Base::Script::Option> for more information.
 
-=head2 Logging methods
-
-Role implements the following methods for logging
-
-=over 4
-
-=item B<debug>
-
-=item B<info>
-
-=item B<warn>
-
-=item B<error> - note, that this also terminates the process
-
-=back
-
 =head2 Options handling
 
 One of the most useful parts of App::Base::Script::Common is the simplified access to
