@@ -1,7 +1,5 @@
 package App::Base::Script::OnlyOne;
 use Moose::Role;
-our $VERSION = "0.04";
-$VERSION = eval $VERSION;
 
 use Path::Tiny;
 use File::Flock::Tiny;
@@ -12,7 +10,7 @@ App::Base::Script::OnlyOne - do not allow more than one instance running
 
 =head1 VERSION
 
-This document describes App::Base version 0.04
+This document describes App::Base version 0.05
 
 =head1 SYNOPSIS
 
@@ -25,7 +23,7 @@ This document describes App::Base version 0.04
 With this role your script will refuse to start if another copy of the script
 is running already (or if it is deadlocked or entered an infinite loop because
 of programming error). After start it tries to lock pid file, and if this is
-not possible, it croaks.
+not possible, it dies.
 
 =cut
 
